@@ -6,6 +6,7 @@ ABBR_RE = re.compile(r'^[a-zA-Z]{2}$')
 
 STATES = []
 TERRITORIES = []
+OBSOLETE = []
 STATES_AND_TERRITORIES = []
 
 _lookup_cache = {}
@@ -24,6 +25,10 @@ class State(object):
         return self.name
 
     def shapefile_urls(self, region=None):
+
+        if not self.fips:
+            return {}
+
         base_url = "http://www2.census.gov/geo/tiger/TIGER2010"
         urls = {
             'tract': base_url + '/TRACT/2010/tl_2010_%s_tract10.zip' % self.fips,
@@ -34,8 +39,10 @@ class State(object):
             'block': base_url + '/TABBLOCK/2010/tl_2010_%s_tabblock10.zip' % self.fips,
             'blockgroup': base_url + '/BG/2010/tl_2010_%s_bg10.zip' % self.fips
         }
+
         if region and region in urls:
             return urls[region]
+
         return urls
 
 
@@ -55,8 +62,10 @@ def load_states():
 
             state = State(**s)  # create state object
 
-            # create separate lists for states and territories
-            if state.is_territory:
+            # create separate lists for obsolete, states, and territories
+            if state.is_obsolete:
+                OBSOLETE.append(state)
+            elif state.is_territory:
                 TERRITORIES.append(state)
             else:
                 STATES.append(state)
